@@ -1,4 +1,4 @@
-from mitosheet.sheet_functions.types.utils import get_mito_type
+from mitosheet.sheet_functions.types.utils import NUMBER_SERIES, get_mito_type
 import pandas as pd
 import json
 
@@ -23,7 +23,7 @@ def get_column_describe(send, event, wsc):
             # to the front-end.
 
             # If the series is a number, round the statistics so they look good.
-            if get_mito_type(series) == 'number_series':
+            if get_mito_type(series) == NUMBER_SERIES:
                 row = round(row, 2)
 
             describe_obj[index] = str(row)
@@ -32,7 +32,7 @@ def get_column_describe(send, event, wsc):
         describe_obj['count: NaN'] = str(series.isna().sum())
 
         # NOTE: be careful adding things here, as we dont want to destroy performance 
-        if get_mito_type(series) == 'number_series':
+        if get_mito_type(series) == NUMBER_SERIES:
             describe_obj['median'] = str(round(series.median(), 2))
             describe_obj['sum'] = str(round(series.sum(), 2))
 
