@@ -1,14 +1,8 @@
-#!/usr/bin/env python
-# coding: utf-8
-
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
 import os
 from pathlib import Path
-from typing import Any, Dict, List, Tuple
 
 
-def get_filenames_with_suffix(*suffixes: str) -> List[str]:
+def get_filenames_with_suffix(*suffixes):
     """
     Returns all the file names in the current folder that end with the given
     suffix, sorted from most-recently created to the oldest.
@@ -20,7 +14,7 @@ def get_filenames_with_suffix(*suffixes: str) -> List[str]:
     return [str(filename) for filename in filenames if filename.suffix in suffixes]
 
 
-def get_datafiles(params: Dict[str, Any]) -> List[str]:
+def get_datafiles(send, event):
     """
     Handles a `datafiles` api call, and returns all the csv files
     in the current folder.
@@ -31,4 +25,8 @@ def get_datafiles(params: Dict[str, Any]) -> List[str]:
         '.tab',
     )
     # TODO: also get the XLSX files, when we can import them
-    return csv_files
\ No newline at end of file
+    send({
+        'event': 'api_response',
+        'id': event['id'],
+        'data': csv_files
+    })
\ No newline at end of file
