@@ -12,7 +12,7 @@ from typing import Tuple, Union
 import pandas as pd
 import numpy as np
 
-from mitosheet.sheet_functions.types.utils import get_mito_type
+from mitosheet.sheet_functions.types.utils import BOOLEAN_SERIES, DATETIME_SERIES, NUMBER_SERIES, STRING_SERIES, get_mito_type
 
 
 def to_boolean_series(
@@ -33,14 +33,14 @@ def to_boolean_series(
         unknown_object = pd.Series([unknown_object])
         from_type = get_mito_type(unknown_object)
 
-    if from_type == 'boolean_series':
+    if from_type == BOOLEAN_SERIES:
         return unknown_object
-    elif from_type == 'datetime_series':
+    elif from_type == DATETIME_SERIES:
         # For now, we treat all dates as true, and NaN values as False
         return ~unknown_object.isna()
-    elif from_type == 'number_series':
+    elif from_type == NUMBER_SERIES:
         return unknown_object.astype('bool')
-    elif from_type == 'string_series':
+    elif from_type == STRING_SERIES:
         return unknown_object.astype('bool')
     else:
         return None
\ No newline at end of file
