@@ -6,8 +6,8 @@
 
 import pytest
 
-from ..errors import EditError
-from ..parser import parse_formula, safe_replace, safe_contains
+from mitosheet.errors import EditError
+from mitosheet.parser import parse_formula, safe_replace, safe_contains
 
 CONSTANT_TEST_CASES = [
     (
