@@ -11,6 +11,7 @@ This file contains helpful functions and classes for testing operations.
 from typing import List
 from mitosheet.utils import get_new_step_id
 import pandas as pd
+from mitosheet.transpiler.transpile import transpile
 
 from mitosheet.example import sheet, MitoWidget
 import json
@@ -27,6 +28,10 @@ class MitoWidgetTestWrapper:
     def __init__(self, mito_widget: MitoWidget):
         self.mito_widget = mito_widget
 
+    @property
+    def transpiled_code(self):
+        return transpile(self.mito_widget.widget_state_container)['code']
+
     def add_column(self, sheet_index: int, column_header: str, column_header_index=-1):
         """
         Adds a column.
@@ -218,16 +223,16 @@ class MitoWidgetTestWrapper:
             }
         )
 
-    def change_column_type(self, sheet_index: int, column_header: str, new_column_type: str):
+    def change_column_dtype(self, sheet_index: int, column_header: str, new_dtype: str):
         self.mito_widget.receive_message(
             self.mito_widget,
             {
                 'event': 'edit_event',
-                'type': 'change_column_type_edit',
+                'type': 'change_column_dtype_edit',
                 'step_id': get_new_step_id(),
                 'sheet_index': sheet_index,
                 'column_header': column_header,
-                'new_column_type': new_column_type
+                'new_dtype': new_dtype
             }
         )
 
